clear all 

set scheme modern

if c(username) == "mattiashallberg"{
    cd "/Users/mattiashallberg/Library/CloudStorage/Dropbox/PhD/TA/Political Economics II/2025/PS1/solution/code"
}
if c(username) == "maha9905"{
    cd "C:\Users\maha9905\Dropbox\PhD\TA\Political Economics II\2025\PS1\solution\code"
}

cap frame drop politics
frame create politics
frame politics{
    import excel ../input/suffrage_data/data.xlsx, sheet("Full_Franchise") firstrow clear
    missings dropvars , force 
    drop Pathnote 
}

cap frame drop expenditure
frame create expenditure
frame expenditure{
    import excel ../input/suffrage_data/data.xlsx, sheet("exp") firstrow clear allstring
    ** clean some data 
    drop if _n == 1 
    * rename variables
    rename Governmentexpenditurepercent CountryName 
    drop if CountryName == "©IMF, 2023"
    foreach var of var ? ??{
        local varlab: variable label `var'
        rename `var' exp`varlab' 
    }
    foreach var of var exp*{
        replace `var' = "" if `var' == "no data"
    }
    foreach var of var exp*{
        destring `var', replace force 
    }
    missings dropobs  , force 

    * Make long

    reshape long exp, i(CountryName) j(year)
}

** Investigate how well country names match
tempfile p e 
frame politics{
    preserve
    keep CountryName ccode
    save `p'
    restore 
} 
frame expenditure{
    preserve
    keep CountryName
    bys CountryName: keep if _n == 1
    save `e'
    restore 
}
use `p' , clear 
merge 1:m CountryName using `e'
** Use information to recode some CountryName
frame expenditure{
    replace CountryName = "Antigua and" if CountryName == "Antigua and Barbuda"
    replace CountryName = "Bosnia Herze" if CountryName == "Bosnia and Herzegovina"
    replace CountryName = "Cape Verde" if CountryName == "Cabo Verde"
    replace CountryName = "Central Afric" if CountryName == "Central African Republic"
    replace CountryName = "China" if CountryName == "China, People's Republic of"
    replace CountryName = "Congo, Dem." if CountryName == "Congo, Dem. Rep. of the"
    replace CountryName = "Congo, Rep." if CountryName == "Congo, Republic of "
    replace CountryName = "Cote d'Ivoire" if CountryName == "Côte d'Ivoire"
    replace CountryName = "Dominican R" if CountryName == "Dominican Republic"
    replace CountryName = "Guinea- Biss" if CountryName == "Guinea-Bissau"
    replace CountryName = "Guinea, Equa" if CountryName == "Equatorial Guinea"
    replace CountryName = "Iran, Islamic" if CountryName == "Iran"
    replace CountryName = "Korea, Repub" if CountryName == "Korea, Republic of"
    replace CountryName = "Marshall Isla" if CountryName == "Marshall Islands"
    replace CountryName = "Micronesia, F" if CountryName == "Micronesia, Fed. States of"
    replace CountryName = "Papa New Gu" if CountryName == "Papua New Guinea"
    replace CountryName = "Saint Kitts an" if CountryName == "Saint Kitts and Nevis"
    replace CountryName = "Solomon Isla" if CountryName == "Solomon Islands"
    replace CountryName = "Trinidad and" if CountryName == "Trinidad and Tobago"
    replace CountryName = "Turkey" if CountryName == "Türkiye, Republic of"
    replace CountryName = "United Kingd" if CountryName == "United Kingdom"
    replace CountryName = "Yemen, Rep." if CountryName == "Yemen"
}

** Merge 
tempfile p e 
frame politics: save `p'
frame expenditure: save `e'

use `p' , clear 
merge 1:m CountryName using `e', keep(3) nogen

sort CountryName year 

** Very big pitcture
preserve
    collapse (mean) exp , by(year)
    tw line exp year , ytitle("Percent of GDP") xtitle("Year") 
restore 

** First a big picture
tw (scatter exp Full_Franchis if year == 2022) (lfit exp Full_Franchis if year == 2022) , legend(lab(1 "Gov exp in 2022")) xtitle("Year of full franchise for women") ytitle("Percent of GDP")
tw (scatter exp Full_Franchis if year == 2022, by(Path)) (lfit exp Full_Franchis if year == 2022, by(Path)) , legend(lab(1 "Gov exp in 2022")) xtitle("Year of full franchise for women") ytitle("Percent of GDP")


** Set up for event study 
gen year_relative_franchise = year - Full_Franchis


drop if exp == . 
egen min_year = min(year_relative_franchise), by(CountryName)
drop if min_year >= 0 // Countries without data before suffrage is not possible to study.
*Leaving us with only 41 countries. 

preserve 
    * For a fairly balanced panel
    keep if inrange(year_relative_franchise,-20,20)
    collapse (mean) exp , by(year_relative_franchise)
    tw line exp year_relative_franchise
    restore

preserve 
    * For a fairly balanced panel
    keep if inrange(year_relative_franchise,-20,20)
    collapse (mean) exp , by(year_relative_franchise Path)
    tw line exp year_relative_franchise, by(Path)
restore

preserve 
    * For a fairly balanced panel
    keep if inrange(year_relative_franchise,-20,20)
    collapse (mean) exp , by(year_relative_franchise suffragedeca)
    tw line exp year_relative_franchise if suffragedeca < 2000, by(suffragedeca)
restore

** TWFE event study 
preserve
    tab year_relative_franchise if inrange(year_relative_franchise,-40,40), gen(d)
    reghdfe exp d1-d39 d41-d81 if inrange(year_relative_franchise,-40,40),  absorb(CountryName year) cluster(CountryName)
    coefplot, drop(_cons) gen replace 

    replace __at = __at - 40
    replace __at = __at +1 if __at >= 0
    replace __at = 0 if _n == 80 
    replace __b = 0 if __at == 0

    tw (scatter __b __at) (rcap __ll1 __ul1 __at), legend(off)
restore 

preserve 
    * Callaway Sant'Anna
    keep if inrange(year_relative_franchise,-40,40)
    egen i = group(CountryName)
    gen t = year
    gen g = Full_Franchis

    csdid2 exp, i(i) t(t) g(g) notyet
    estat event, plot 
restore